using System;
using System.Web.UI;
using System.IO;
using System.Text;
using System.Web.UI.WebControls;

namespace ASP
{

    public partial class default_aspx : ICallbackEventHandler
    {
        public string sCallBackFunctionInvocation;

        void Page_Load(object sender, System.EventArgs e)
        {
            // create callback code
            sCallBackFunctionInvocation = this.GetCallbackEventReference(this, "sMessage", "CallBackReturnFunction", "oContext", "OnCallBackError") + ";";

            // hook into tree node population event
            FolderTree.TreeNodePopulate += new TreeNodeEventHandler(FolderTree_TreeNodePopulate);

            // For the intial load, we need to add the root-node
            if (!Page.IsPostBack)
            {
                TreeNode rootNode = new TreeNode(@"c:\", "c:");
                rootNode.NavigateUrl = @"javascript:OnFolderClick('c:\\');";
                rootNode.PopulateOnDemand = true;
                FolderTree.Nodes.Add(rootNode);
            }

        }

        private void FolderTree_TreeNodePopulate(object sender, TreeNodeEventArgs e)
        {
            // obtain the current Directory
            DirectoryInfo currentDirectory = new DirectoryInfo(e.Node.ValuePath + FolderTree.PathSeparator);

            if (currentDirectory.Exists)
            {
                // go through each sub directory
                foreach (DirectoryInfo subDirectory in currentDirectory.GetDirectories())
                {
                    // and create a new tree node for each of them
                    TreeNode subNode = new TreeNode(subDirectory.Name, subDirectory.Name);
                    subNode.NavigateUrl = "javascript:OnFolderClick('" + subDirectory.FullName.Replace("\\", "\\\\") + "');";
                    subNode.PopulateOnDemand = true;

                    // add new sub-node to the current node
                    e.Node.ChildNodes.Add(subNode);
                }
            }
        }


        public string RaiseCallbackEvent(string eventArgument)
        {
            StringBuilder sReturnValue = new StringBuilder();

            // if a directory is requested
            if (Directory.Exists(eventArgument))
            {
                // create a pipe-delimited list of sub directories
                foreach (string sFile in Directory.GetFiles(eventArgument))
                    sReturnValue.Append(Path.GetFileName(sFile) + "|");

                return sReturnValue.ToString().TrimEnd('|');
            }
            else if (File.Exists(eventArgument))
            {
                // if a file is requested
                FileInfo oFile = new FileInfo(eventArgument);

                // create message for file properties
                sReturnValue.Append("File Size: \t" + oFile.Length / 1024 + " kb" + Environment.NewLine);
                sReturnValue.Append("Creation Time:\t" + oFile.CreationTime + Environment.NewLine);
                sReturnValue.Append("Access Time: \t" + oFile.LastAccessTime + Environment.NewLine);
                sReturnValue.Append("Write Time: \t" + oFile.LastWriteTime + Environment.NewLine);

                // return return value
                return sReturnValue.ToString();
            }
            else
                throw new System.ApplicationException("Invalid message (" + eventArgument + ") was passed to server.");
        }
    }
}
